require 'studio_game/game'

module StudioGame
  describe Game do

    before do
      @game = Game.new("Knuckleheads")
    
      @initial_health = 100
      @player = Player.new("moe", @initial_health)
    
      @game.add_player(@player)
    
      $stdout = StringIO.new
      @turns = 10
    end
  
    it 'should increase health by a multiple of 15 when a high number is rolled that many times' do
      allow_any_instance_of(Die).to receive(:roll).and_return(5)
    
      @game.play(@turns)
    
      expect(@player.health).to eq @initial_health + (15 * @turns)
    end
  
    it 'should skip the player when a medium number is rolled' do
      allow_any_instance_of(Die).to receive(:roll).and_return(3)
    
      @game.play(@turns)

      expect(@player.health).to eq @initial_health
    end

    it 'should decrease health by a multiple of 10 when a low number is rolled that many times' do
      allow_any_instance_of(Die).to receive(:roll).and_return(1)

      @game.play(@turns)
    
      expect(@player.health).to eq @initial_health - (10 * @turns)
    end
  
    it 'assigns a treasure for points during a player\'s turn' do
      game = Game.new("Knuckleheads")
      player = Player.new("moe")
    
      game.add_player(player)
      game.play(1)
    
      expect(player.points).not_to be_zero
    end
  
    it 'computes total points as the sum of all player points' do
      game = Game.new("Knuckleheads")
  
      player1 = Player.new("moe")
      player2 = Player.new("larry")
  
      game.add_player(player1)
      game.add_player(player2)
  
      player1.found_treasure(Treasure.new(:hammer, 50))
      player1.found_treasure(Treasure.new(:hammer, 50))
      player2.found_treasure(Treasure.new(:crowbar, 400))
  
      expect(game.total_points).to eq 500
    end
  end
end